# Downloading Reports from the SAP LeanIX Store
### On this page
  * [Introduction to the SAP LeanIX Store](https://help.sap.com/docs/leanix/ea/download-reports#introduction-to-the-sap-leanix-store)
  * [Downloading a Report](https://help.sap.com/docs/leanix/ea/download-reports#downloading-a-report)
  * [Activating a Report](https://help.sap.com/docs/leanix/ea/download-reports#activating-a-report)


Download custom reports from the SAP LeanIX Store and make them available to all workspace users.
